<?php
/**
 * Skin Setup
 *
 * @package HYGIA
 * @since HYGIA 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'hygia_theme_defaults' ) ) {
	function hygia_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 60,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( $value === '' && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// WOOCOMMERCE SETUP
//--------------------------------------------------

// Allow extended layouts for WooCommerce
if ( ! function_exists( 'hygia_skin_woocommerce_allow_extensions' ) ) {
	add_filter( 'hygia_filter_load_woocommerce_extensions', 'hygia_skin_woocommerce_allow_extensions' );
	function hygia_skin_woocommerce_allow_extensions( $allow ) {
		return false;
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'hygia_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'hygia_skin_setup', 1 );
	function hygia_skin_setup() {

		$GLOBALS['HYGIA_STORAGE'] = array_merge( $GLOBALS['HYGIA_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-axiom',

			'theme_doc_url'       => '//hygia.axiomthemes.com/doc',

			'theme_demofiles_url' => '//demofiles.axiomthemes.com/hygia/',
			
			'theme_rate_url'      => '//themeforest.net/download',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

			'theme_download_url'  => '//1.envato.market/9Wv7Mj',        // Axiom

			'theme_video_url'     => '//www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',   // Axiom

			'theme_privacy_url'   => '//axiomthemes.com/privacy-policy/',                   // Axiom

			'portfolio_url'       => '//themeforest.net/user/ancorathemes/portfolio',        // Axiom

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}


// Add/remove/change Theme Settings
if ( ! function_exists( 'hygia_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'hygia_skin_setup_settings', 1 );
	function hygia_skin_setup_settings() {
		// Example: enable (true) / disable (false) thumbs in the prev/next navigation
		hygia_storage_set_array( 'settings', 'thumbs_in_navigation', false );
		hygia_storage_set_array2( 'required_plugins', 'latepoint', 'install', false);
		hygia_storage_set_array2( 'required_plugins', 'instagram-feed', 'install', false);
		hygia_storage_set_array2( 'required_plugins', 'quickcal', 'install', true);
		hygia_storage_set_array2( 'required_plugins', 'woocommerce', 'install', true);
		hygia_storage_set_array2( 'required_plugins', 'ti-woocommerce-wishlist', 'install', true);
		hygia_storage_set_array2( 'required_plugins', 'elegro-payment', 'install', true);
	}
}



//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'hygia_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'hygia_skin_setup_fonts', 1 );
	function hygia_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		hygia_storage_set(
			'load_fonts', array(
				array(
					'name'   => 'halyard-display',
					'family' => 'sans-serif',
					'link'   => 'https://use.typekit.net/xog3vbp.css',
					'styles' => ''
				),
				// Google font
				array(
					'name'   => 'DM Sans',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'ital,wght@0,400;0,500;0,700;1,400;1,500;1,700',     // Parameter 'style' used only for the Google fonts
				)
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		hygia_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => basekit_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'hygia' );

		hygia_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'hygia' ) ),
					'font-family'     => '"DM Sans",sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.68em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.7em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'hygia' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '3.353em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.04em',
					'margin-bottom'   => '0.46em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '2.765em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.021em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.67em',
					'margin-bottom'   => '0.56em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '2.059em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.029em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.94em',
					'margin-bottom'   => '0.72em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '1.647em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.036em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.15em',
					'margin-bottom'   => '0.83em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '1.412em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.083em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.3em',
					'margin-bottom'   => '0.84em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '1.118em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.263em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.75em',
					'margin-bottom'   => '1.1em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '1.7em',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '14px',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '21px',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '1.5px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'hygia' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '16px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'hygia' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '14px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
					'font-size'       => '17px',
					'font-weight'     => '500',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'hygia' ) ),
					'font-family'     => '"DM Sans",sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'hygia' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'hygia' ) ),
					'font-family'     => 'halyard-display,sans-serif',
				),
			)
		);

		// Font presets
		hygia_storage_set(
			'font_presets', array(
				'karla' => array(
								'title'  => esc_html__( 'Karla', 'hygia' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Dancing Script',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
													// Google font
													array(
														'name'   => 'Sansita Swashed',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Dancing Script",fantasy',
														'font-size'       => '1.25rem',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
														'font-size'       => '4em',
													),
													'h2'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h3'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h4'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h5'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h6'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'logo'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'button'  => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'submenu' => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
												),
							),
				'roboto' => array(
								'title'  => esc_html__( 'Roboto', 'hygia' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Noto Sans JP',
														'family' => 'serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
													// Google font
													array(
														'name'   => 'Merriweather',
														'family' => 'sans-serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Noto Sans JP",serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
												),
							),
				'garamond' => array(
								'title'  => esc_html__( 'Garamond', 'hygia' ),
								'load_fonts' => array(
													// Adobe font
													array(
														'name'   => 'Europe',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
													// Adobe font
													array(
														'name'   => 'Sofia Pro',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Sofia Pro",sans-serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Europe,sans-serif',
													),
												),
							),
			)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'hygia_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'hygia_skin_setup_schemes', 1 );
	function hygia_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		hygia_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'hygia' ),
					'description' => esc_html__( 'Colors of the main content area', 'hygia' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'hygia' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'hygia' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'hygia' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'hygia' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'hygia' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'hygia' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'hygia' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'hygia' ),
				),
			)
		);

		hygia_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'hygia' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'hygia' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'hygia' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'hygia' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'hygia' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'hygia' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'hygia' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'hygia' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'hygia' ),
					'description' => esc_html__( 'Color of the text inside this block', 'hygia' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'hygia' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'hygia' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'hygia' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'hygia' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'hygia' ),
					'description' => esc_html__( 'Color of the links inside this block', 'hygia' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'hygia' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'hygia' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'hygia' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'hygia' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'hygia' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'hygia' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'hygia' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'hygia' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'hygia' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'hygia' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F4FAFA',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#32B4B4',
					'text_hover'       => '#1EA2A2',
					'text_link2'       => '#A6D118',
					'text_hover2'      => '#93BC0A',
					'text_link3'       => '#7DBFBF',
					'text_hover3'      => '#66AFAF',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#32B4B4',
					'alter_hover'      => '#1EA2A2',
					'alter_link2'      => '#A6D118',
					'alter_hover2'     => '#93BC0A',
					'alter_link3'      => '#7DBFBF',
					'alter_hover3'     => '#66AFAF',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#32B4B4',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#052229',
					'bd_color'         => '#163A43',

					// Text and links colors
					'text'             => '#9BADB3',
					'text_light'       => '#6E7B80',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#32B4B4',
					'text_hover'       => '#1EA2A2',
					'text_link2'       => '#A6D118',
					'text_hover2'      => '#93BC0A',
					'text_link3'       => '#7DBFBF',
					'text_hover3'      => '#66AFAF',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#062A33',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#163A43',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#9BADB3',
					'alter_light'      => '#6E7B80',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#32B4B4',
					'alter_hover'      => '#1EA2A2',
					'alter_link2'      => '#A6D118',
					'alter_hover2'     => '#93BC0A',
					'alter_link3'      => '#7DBFBF',
					'alter_hover3'     => '#66AFAF',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#32B4B4',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#163A43',
					'input_bd_hover'   => '#163A43',
					'input_text'       => '#9BADB3',
					'input_light'      => '#9BADB3',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'light'
			'light' => array(
				'title'    => esc_html__( 'Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#32B4B4',
					'text_hover'       => '#1EA2A2',
					'text_link2'       => '#A6D118',
					'text_hover2'      => '#93BC0A',
					'text_link3'       => '#7DBFBF',
					'text_hover3'      => '#66AFAF',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F4FAFA',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#32B4B4',
					'alter_hover'      => '#1EA2A2',
					'alter_link2'      => '#A6D118',
					'alter_hover2'     => '#93BC0A',
					'alter_link3'      => '#7DBFBF',
					'alter_hover3'     => '#66AFAF',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#32B4B4',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'violet_default'
			'violet_default' => array(
				'title'    => esc_html__( 'Violet Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F7F7F7',
					'bd_color'         => '#E1E1E1',

					// Text and links colors
					'text'             => '#97979E',
					'text_light'       => '#B4B4B4',
					'text_dark'        => '#27002A',
					'text_link'        => '#3AB795',
					'text_hover'       => '#34A586',
					'text_link2'       => '#782382',
					'text_hover2'      => '#692071',
					'text_link3'       => '#0EB1C7',
					'text_hover3'      => '#0CA1B5',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#E1E1E1',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#97979E',
					'alter_light'      => '#B4B4B4',
					'alter_dark'       => '#27002A',
					'alter_link'       => '#3AB795',
					'alter_hover'      => '#34A586',
					'alter_link2'      => '#782382',
					'alter_hover2'     => '#692071',
					'alter_link3'      => '#0EB1C7',
					'alter_hover3'     => '#0CA1B5',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#180418',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#B6B6BF',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#3AB795',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#E1E1E1',
					'input_bd_hover'   => '#27002A',
					'input_text'       => '#B4B4B4',
					'input_light'      => '#B4B4B4',
					'input_dark'       => '#27002A',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#27002A',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'violet_dark'
			'violet_dark'    => array(
				'title'    => esc_html__( 'Violet Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#180418',
					'bd_color'         => '#3D353D',
  
					// Text and links colors
					'text'             => '#C7C7D1',
					'text_light'       => '#84848B',
					'text_dark'        => '#FFFFFF',
					'text_link'        => '#3AB795',
					'text_hover'       => '#34A586',
					'text_link2'       => '#782382',
					'text_hover2'      => '#692071',
					'text_link3'       => '#0EB1C7',
					'text_hover3'      => '#0CA1B5',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#211721',
					'alter_bg_hover'   => '#241C24',
					'alter_bd_color'   => '#3D353D',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#C7C7D1',
					'alter_light'      => '#84848B',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#3AB795',
					'alter_hover'      => '#34A586',
					'alter_link2'      => '#782382',
					'alter_hover2'     => '#692071',
					'alter_link3'      => '#0EB1C7',
					'alter_hover3'     => '#0CA1B5',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#180418',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#B6B6BF',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#3AB795',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#3D353D',
					'input_bd_hover'   => '#3D353D',
					'input_text'       => '#C7C7D1',
					'input_light'      => '#C7C7D1',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#27002A',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#27002A',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'violet_light'
			'violet_light' => array(
				'title'    => esc_html__( 'Violet Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#E1E1E1',

					// Text and links colors
					'text'             => '#97979E',
					'text_light'       => '#B4B4B4',
					'text_dark'        => '#27002A',
					'text_link'        => '#3AB795',
					'text_hover'       => '#34A586',
					'text_link2'       => '#782382',
					'text_hover2'      => '#692071',
					'text_link3'       => '#0EB1C7',
					'text_hover3'      => '#0CA1B5',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F7F7F7',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#E1E1E1',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#97979E',
					'alter_light'      => '#B4B4B4',
					'alter_dark'       => '#27002A',
					'alter_link'       => '#3AB795',
					'alter_hover'      => '#34A586',
					'alter_link2'      => '#782382',
					'alter_hover2'     => '#692071',
					'alter_link3'      => '#0EB1C7',
					'alter_hover3'     => '#0CA1B5',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#180418',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#B6B6BF',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#3AB795',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#E1E1E1',
					'input_bd_hover'   => '#27002A',
					'input_text'       => '#B4B4B4',
					'input_light'      => '#B4B4B4',
					'input_dark'       => '#27002A',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#27002A',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			
			// Color scheme: 'turquoise_default'
			'turquoise_default' => array(
				'title'    => esc_html__( 'Turquoise Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F4FAFA',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#FFC107',
					'text_hover'       => '#EDB100',
					'text_link2'       => '#68BCB7',
					'text_hover2'      => '#5AA8A4',
					'text_link3'       => '#9683FF',
					'text_hover3'      => '#6754F7',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#FFC107',
					'alter_hover'      => '#EDB100',
					'alter_link2'      => '#68BCB7',
					'alter_hover2'     => '#5AA8A4',
					'alter_link3'      => '#9683FF',
					'alter_hover3'     => '#6754F7',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#FFC107',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'turquoise_dark'
			'turquoise_dark'    => array(
				'title'    => esc_html__( 'Turquoise Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#052229',
					'bd_color'         => '#163A43',

					// Text and links colors
					'text'             => '#9BADB3',
					'text_light'       => '#6E7B80',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#FFC107',
					'text_hover'       => '#EDB100',
					'text_link2'       => '#68BCB7',
					'text_hover2'      => '#5AA8A4',
					'text_link3'       => '#9683FF',
					'text_hover3'      => '#6754F7',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#062A33',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#163A43',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#9BADB3',
					'alter_light'      => '#6E7B80',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#FFC107',
					'alter_hover'      => '#EDB100',
					'alter_link2'      => '#68BCB7',
					'alter_hover2'     => '#5AA8A4',
					'alter_link3'      => '#9683FF',
					'alter_hover3'     => '#6754F7',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#FFC107',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#163A43',
					'input_bd_hover'   => '#163A43',
					'input_text'       => '#9BADB3',
					'input_light'      => '#9BADB3',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'turquoise_light'
			'turquoise_light' => array(
				'title'    => esc_html__( 'Turquoise Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#FFC107',
					'text_hover'       => '#EDB100',
					'text_link2'       => '#68BCB7',
					'text_hover2'      => '#5AA8A4',
					'text_link3'       => '#9683FF',
					'text_hover3'      => '#6754F7',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F4FAFA',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#FFC107',
					'alter_hover'      => '#EDB100',
					'alter_link2'      => '#68BCB7',
					'alter_hover2'     => '#5AA8A4',
					'alter_link3'      => '#9683FF',
					'alter_hover3'     => '#6754F7',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#062A33',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#FFC107',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'blue_default'
			'blue_default' => array(
				'title'    => esc_html__( 'Blue Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F9FC',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#4977E5',
					'text_hover'       => '#3062D8',
					'text_link2'       => '#70C9AC',
					'text_hover2'      => '#59B799',
					'text_link3'       => '#A5C0FF',
					'text_hover3'      => '#6F94EA',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#4977E5',
					'alter_hover'      => '#3062D8',
					'alter_link2'      => '#70C9AC',
					'alter_hover2'     => '#59B799',
					'alter_link3'      => '#A5C0FF',
					'alter_hover3'     => '#6F94EA',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#4977E5',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'blue_dark'
			'blue_dark'    => array(
				'title'    => esc_html__( 'Blue Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#071426',
					'bd_color'         => '#182D4B',

					// Text and links colors
					'text'             => '#9BA9B3',
					'text_light'       => '#6E7780',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#4977E5',
					'text_hover'       => '#3062D8',
					'text_link2'       => '#70C9AC',
					'text_hover2'      => '#59B799',
					'text_link3'       => '#A5C0FF',
					'text_hover3'      => '#6F94EA',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#0A1A31',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#182D4B',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#9BA9B3',
					'alter_light'      => '#6E7780',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#4977E5',
					'alter_hover'      => '#3062D8',
					'alter_link2'      => '#70C9AC',
					'alter_hover2'     => '#59B799',
					'alter_link3'      => '#A5C0FF',
					'alter_hover3'     => '#6F94EA',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#4977E5',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#182D4B',
					'input_bd_hover'   => '#182D4B',
					'input_text'       => '#9BA9B3',
					'input_light'      => '#9BA9B3',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'blue_light'
			'blue_light' => array(
				'title'    => esc_html__( 'Blue Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#4977E5',
					'text_hover'       => '#3062D8',
					'text_link2'       => '#70C9AC',
					'text_hover2'      => '#59B799',
					'text_link3'       => '#A5C0FF',
					'text_hover3'      => '#6F94EA',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F5F9FC',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#4977E5',
					'alter_hover'      => '#3062D8',
					'alter_link2'      => '#70C9AC',
					'alter_hover2'     => '#59B799',
					'alter_link3'      => '#A5C0FF',
					'alter_hover3'     => '#6F94EA',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BADB3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#4977E5',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'peach_default'
			'peach_default' => array(
				'title'    => esc_html__( 'Peach Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F8FAFA',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#EC5F56',
					'text_hover'       => '#E6473D',
					'text_link2'       => '#3232C9',
					'text_hover2'      => '#2020C1',
					'text_link3'       => '#C5A48E',
					'text_hover3'      => '#AB8E7A',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#EC5F56',
					'alter_hover'      => '#E6473D',
					'alter_link2'      => '#3232C9',
					'alter_hover2'     => '#2020C1',
					'alter_link3'      => '#C5A48E',
					'alter_hover3'     => '#AB8E7A',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#EC5F56',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'peach_dark'
			'peach_dark'    => array(
				'title'    => esc_html__( 'Peach Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#071426',
					'bd_color'         => '#182D4B',

					// Text and links colors
					'text'             => '#9BA9B3',
					'text_light'       => '#6E7780',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#EC5F56',
					'text_hover'       => '#E6473D',
					'text_link2'       => '#3232C9',
					'text_hover2'      => '#2020C1',
					'text_link3'       => '#C5A48E',
					'text_hover3'      => '#AB8E7A',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#0A1A31',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#182D4B',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#9BA9B3',
					'alter_light'      => '#6E7780',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#EC5F56',
					'alter_hover'      => '#E6473D',
					'alter_link2'      => '#3232C9',
					'alter_hover2'     => '#2020C1',
					'alter_link3'      => '#C5A48E',
					'alter_hover3'     => '#AB8E7A',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#EC5F56',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#182D4B',
					'input_bd_hover'   => '#182D4B',
					'input_text'       => '#9BA9B3',
					'input_light'      => '#9BA9B3',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'peach_light'
			'peach_light' => array(
				'title'    => esc_html__( 'Peach Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#EC5F56',
					'text_hover'       => '#E6473D',
					'text_link2'       => '#3232C9',
					'text_hover2'      => '#2020C1',
					'text_link3'       => '#C5A48E',
					'text_hover3'      => '#AB8E7A',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F8FAFA',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#EC5F56',
					'alter_hover'      => '#E6473D',
					'alter_link2'      => '#3232C9',
					'alter_hover2'     => '#2020C1',
					'alter_link3'      => '#C5A48E',
					'alter_hover3'     => '#AB8E7A',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#EC5F56',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'aqua_default'
			'aqua_default' => array(
				'title'    => esc_html__( 'Aqua Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F9FC',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#1DACE6',
					'text_hover'       => '#0E9AD3',
					'text_link2'       => '#103BA5',
					'text_hover2'      => '#01298D',
					'text_link3'       => '#7093EA',
					'text_hover3'      => '#456ED6',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#1DACE6',
					'alter_hover'      => '#0E9AD3',
					'alter_link2'      => '#103BA5',
					'alter_hover2'     => '#01298D',
					'alter_link3'      => '#7093EA',
					'alter_hover3'     => '#456ED6',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#1DACE6',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'aqua_dark'
			'aqua_dark'    => array(
				'title'    => esc_html__( 'Aqua Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#071426',
					'bd_color'         => '#182D4B',

					// Text and links colors
					'text'             => '#9BA9B3',
					'text_light'       => '#6E7780',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#1DACE6',
					'text_hover'       => '#0E9AD3',
					'text_link2'       => '#103BA5',
					'text_hover2'      => '#01298D',
					'text_link3'       => '#7093EA',
					'text_hover3'      => '#456ED6',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#0A1A31',
					'alter_bg_hover'   => '#09192F',
					'alter_bd_color'   => '#182D4B',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#9BA9B3',
					'alter_light'      => '#6E7780',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#1DACE6',
					'alter_hover'      => '#0E9AD3',
					'alter_link2'      => '#103BA5',
					'alter_hover2'     => '#01298D',
					'alter_link3'      => '#7093EA',
					'alter_hover3'     => '#456ED6',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#1DACE6',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#182D4B',
					'input_bd_hover'   => '#182D4B',
					'input_text'       => '#9BA9B3',
					'input_light'      => '#9BA9B3',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'aqua_light'
			'aqua_light' => array(
				'title'    => esc_html__( 'Aqua Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#1DACE6',
					'text_hover'       => '#0E9AD3',
					'text_link2'       => '#103BA5',
					'text_hover2'      => '#01298D',
					'text_link3'       => '#7093EA',
					'text_hover3'      => '#456ED6',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F5F9FC',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#1DACE6',
					'alter_hover'      => '#0E9AD3',
					'alter_link2'      => '#103BA5',
					'alter_hover2'     => '#01298D',
					'alter_link3'      => '#7093EA',
					'alter_hover3'     => '#456ED6',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0A1A31 ',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9BA9B3',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#1DACE6',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_default'
			'red_default' => array(
				'title'    => esc_html__( 'Red Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F9FC',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#F03A03',
					'text_hover'       => '#D83200',
					'text_link2'       => '#F49516',
					'text_hover2'      => '#E3870C',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#F03A03',
					'alter_hover'      => '#D83200',
					'alter_link2'      => '#F49516',
					'alter_hover2'     => '#E3870C',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#F03A03',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_dark'
			'red_dark'    => array(
				'title'    => esc_html__( 'Red Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#1A1D22',
					'bd_color'         => '#292F38',

					// Text and links colors
					'text'             => '#A6AFB5',
					'text_light'       => '#6E7780',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#F03A03',
					'text_hover'       => '#D83200',
					'text_link2'       => '#F49516',
					'text_hover2'      => '#E3870C',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#23262C',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#292F38',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#A6AFB5',
					'alter_light'      => '#6E7780',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#F03A03',
					'alter_hover'      => '#D83200',
					'alter_link2'      => '#F49516',
					'alter_hover2'     => '#E3870C',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#F03A03',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#292F38',
					'input_bd_hover'   => '#292F38',
					'input_text'       => '#A6AFB5',
					'input_light'      => '#A6AFB5',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'red_light'
			'red_light' => array(
				'title'    => esc_html__( 'Red Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#F03A03',
					'text_hover'       => '#D83200',
					'text_link2'       => '#F49516',
					'text_hover2'      => '#E3870C',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F4FAFA',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#F03A03',
					'alter_hover'      => '#D83200',
					'alter_link2'      => '#F49516',
					'alter_hover2'     => '#E3870C',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#F03A03',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'purple_default'
			'purple_default' => array(
				'title'    => esc_html__( 'Purple Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F9FC',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#5258EA',
					'text_hover'       => '#454BDB',
					'text_link2'       => '#18C7A6',
					'text_hover2'      => '#11B294',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#5258EA',
					'alter_hover'      => '#454BDB',
					'alter_link2'      => '#18C7A6',
					'alter_hover2'     => '#11B294',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#5258EA',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'purple_dark'
			'purple_dark'    => array(
				'title'    => esc_html__( 'Purple Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#1A1D22',
					'bd_color'         => '#292F38',

					// Text and links colors
					'text'             => '#A6AFB5',
					'text_light'       => '#6E7780',
					'text_dark'        => '#F4FAFA',
					'text_link'        => '#5258EA',
					'text_hover'       => '#454BDB',
					'text_link2'       => '#18C7A6',
					'text_hover2'      => '#11B294',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#23262C',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#292F38',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#A6AFB5',
					'alter_light'      => '#6E7780',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#5258EA',
					'alter_hover'      => '#454BDB',
					'alter_link2'      => '#18C7A6',
					'alter_hover2'     => '#11B294',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#5258EA',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#292F38',
					'input_bd_hover'   => '#292F38',
					'input_text'       => '#A6AFB5',
					'input_light'      => '#A6AFB5',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#010F34',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'purple_light'
			'purple_light' => array(
				'title'    => esc_html__( 'Purple Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D9E1E2',

					// Text and links colors
					'text'             => '#869194',
					'text_light'       => '#AEB6B8',
					'text_dark'        => '#010F34',
					'text_link'        => '#5258EA',
					'text_hover'       => '#454BDB',
					'text_link2'       => '#18C7A6',
					'text_hover2'      => '#11B294',
					'text_link3'       => '#8392B5',
					'text_hover3'      => '#6B7996',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F5F9FC',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D9E1E2',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#869194',
					'alter_light'      => '#AEB6B8',
					'alter_dark'       => '#010F34',
					'alter_link'       => '#5258EA',
					'alter_hover'      => '#454BDB',
					'alter_link2'      => '#18C7A6',
					'alter_hover2'     => '#11B294',
					'alter_link3'      => '#8392B5',
					'alter_hover3'     => '#6B7996',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#1A1D22',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A6AFB5',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#5258EA',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D9E1E2',
					'input_bd_hover'   => '#010F34',
					'input_text'       => '#AEB6B8',
					'input_light'      => '#AEB6B8',
					'input_dark'       => '#010F34',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#010F34',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'pink_default'
			'pink_default' => array(
				'title'    => esc_html__( 'Pink Default', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FAF7F4',
					'bd_color'         => '#D5CDC6',

					// Text and links colors
					'text'             => '#66696E',
					'text_light'       => '#8D9098',
					'text_dark'        => '#02164E',
					'text_link'        => '#E66D67',
					'text_hover'       => '#D64C45',
					'text_link2'       => '#4063C1',
					'text_hover2'      => '#2C4CA2',
					'text_link3'       => '#7E808A',
					'text_hover3'      => '#5F6169',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff',
					'alter_bg_hover'   => '#F9F9F9',
					'alter_bd_color'   => '#D5CDC6',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#66696E',
					'alter_light'      => '#8D9098',
					'alter_dark'       => '#02164E',
					'alter_link'       => '#E66D67',
					'alter_hover'      => '#D64C45',
					'alter_link2'      => '#4063C1',
					'alter_hover2'     => '#2C4CA2',
					'alter_link3'      => '#7E808A',
					'alter_hover3'     => '#5F6169',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#031839',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A8AFBA',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#E66D67',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D5CDC6',
					'input_bd_hover'   => '#02164E',
					'input_text'       => '#8D9098',
					'input_light'      => '#8D9098',
					'input_dark'       => '#02164E',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#02164E',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'pink_dark'
			'pink_dark'    => array(
				'title'    => esc_html__( 'Pink Dark', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#031839',
					'bd_color'         => '#283A56',

					// Text and links colors
					'text'             => '#A8AFBA',
					'text_light'       => '#8993A2',
					'text_dark'        => '#FCFCFC',
					'text_link'        => '#E66D67',
					'text_hover'       => '#D64C45',
					'text_link2'       => '#4063C1',
					'text_hover2'      => '#2C4CA2',
					'text_link3'       => '#7E808A',
					'text_hover3'      => '#5F6169',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#01132F',
					'alter_bg_hover'   => '#2C313D',
					'alter_bd_color'   => '#283A56',
					'alter_bd_hover'   => '#53535C',
					'alter_text'       => '#A8AFBA',
					'alter_light'      => '#8993A2',
					'alter_dark'       => '#F9F9F9',
					'alter_link'       => '#E66D67',
					'alter_hover'      => '#D64C45',
					'alter_link2'      => '#4063C1',
					'alter_hover2'     => '#2C4CA2',
					'alter_link3'      => '#7E808A',
					'alter_hover3'     => '#5F6169',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#031839',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A8AFBA',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#E66D67',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent',
					'input_bg_hover'   => '#transparent',
					'input_bd_color'   => '#283A56',
					'input_bd_hover'   => '#283A56',
					'input_text'       => '#A8AFBA',
					'input_light'      => '#A8AFBA',
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F9F9F9',
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#02164E',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#02164E',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'pink_light'
			'pink_light' => array(
				'title'    => esc_html__( 'Pink Light', 'hygia' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff',
					'bd_color'         => '#D5CDC6',

					// Text and links colors
					'text'             => '#66696E',
					'text_light'       => '#8D9098',
					'text_dark'        => '#02164E',
					'text_link'        => '#E66D67',
					'text_hover'       => '#D64C45',
					'text_link2'       => '#4063C1',
					'text_hover2'      => '#2C4CA2',
					'text_link3'       => '#7E808A',
					'text_hover3'      => '#5F6169',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FAF7F4',
					'alter_bg_hover'   => '#ffffff',
					'alter_bd_color'   => '#D5CDC6',
					'alter_bd_hover'   => '#DCDCDC',
					'alter_text'       => '#66696E',
					'alter_light'      => '#8D9098',
					'alter_dark'       => '#02164E',
					'alter_link'       => '#E66D67',
					'alter_hover'      => '#D64C45',
					'alter_link2'      => '#4063C1',
					'alter_hover2'     => '#2C4CA2',
					'alter_link3'      => '#7E808A',
					'alter_hover3'     => '#5F6169',

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#031839',
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#A8AFBA',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#E66D67',
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent',
					'input_bg_hover'   => 'transparent',
					'input_bd_color'   => '#D5CDC6',
					'input_bd_hover'   => '#02164E',
					'input_text'       => '#8D9098',
					'input_light'      => '#8D9098',
					'input_dark'       => '#02164E',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#02164E',
					'inverse_link'     => '#ffffff',
					'inverse_hover'    => '#ffffff',

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
		);
		hygia_storage_set( 'schemes', $schemes );
		hygia_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> hygia_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'hygia' ),
		//---> 	'description' => __( 'Description of the new color 1', 'hygia' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		hygia_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
                'alter_dark_015'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.15,
                ),
                'alter_dark_02'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.2,
                ),
                'alter_dark_05'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.5,
                ),
                'alter_dark_08'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.8,
                ),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
                'text_dark_003'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.03,
                ),
                'text_dark_005'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.05,
                ),
                'text_dark_008'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.08,
                ),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
                'text_dark_03'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.3,
                ),
                'text_dark_05'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.5,
                ),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'text_dark_08'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.8,
                ),
                'text_link_007'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.07,
                ),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
                'text_link_03'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.3,
                ),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link2_08'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.8,
                ),
                'text_link2_007'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.07,
                ),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
                'text_link2_03'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.3,
                ),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
                'text_link3_007'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.07,
                ),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
                'text_link3_03'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.3,
                ),
                'inverse_text_03'      => array(
                    'color' => 'inverse_text',
                    'alpha' => 0.3,
                ),
                'inverse_link_08'      => array(
                    'color' => 'inverse_link',
                    'alpha' => 0.8,
                ),
                'inverse_hover_08'      => array(
                    'color' => 'inverse_hover',
                    'alpha' => 0.8,
                ),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		hygia_storage_set(
			'schemes_simple', array(
				'text_link'        => array(),
				'text_hover'       => array(),
				'text_link2'       => array(),
				'text_hover2'      => array(),
				'text_link3'       => array(),
				'text_hover3'      => array(),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
			)
		);

		// Parameters to set order of schemes in the css
		hygia_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		hygia_storage_set(
			'color_presets', array(
				'autumn' => array(
								'title'  => esc_html__( 'Autumn', 'hygia' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	),
												'dark' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	)
												)
							),
				'green' => array(
								'title'  => esc_html__( 'Natural Green', 'hygia' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	),
												'dark' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	)
												)
							),
			)
		);
	}
}


// Activation methods
if ( ! function_exists( 'hygia_skin_filter_activation_methods2' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'hygia_skin_filter_activation_methods2', 11, 1 );
    function hygia_skin_filter_activation_methods2( $args ) {
        $args['elements_key'] = true;
        return $args;
    }
}


// Enqueue skin-specific scripts
if ( ! function_exists( 'hygia_skin_upgrade_style' ) ) {
	add_action( 'wp_enqueue_scripts', 'hygia_skin_upgrade_style', 2040 );
	function hygia_skin_upgrade_style() {
		$hygia_url = hygia_get_file_url( hygia_skins_get_current_skin_dir() . 'skin-upgrade-style.css' );	
		if ( '' != $hygia_url ) {
			wp_enqueue_style( 'hygia-skin-upgrade-style' . esc_attr( hygia_skins_get_current_skin_name() ), $hygia_url, array(), null );
		}
	}
}